@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from google.cloud.artifactregistry import gapic_version as package_version
+from google.cloud.artifactregistry_v1 import gapic_version as package_version
 
 __version__ = package_version.__version__
 
@@ -33,8 +33,20 @@ from .types.apt_artifact import (
 from .types.artifact import (
     DockerImage,
     GetDockerImageRequest,
+    GetMavenArtifactRequest,
+    GetNpmPackageRequest,
+    GetPythonPackageRequest,
     ListDockerImagesRequest,
     ListDockerImagesResponse,
+    ListMavenArtifactsRequest,
+    ListMavenArtifactsResponse,
+    ListNpmPackagesRequest,
+    ListNpmPackagesResponse,
+    ListPythonPackagesRequest,
+    ListPythonPackagesResponse,
+    MavenArtifact,
+    NpmPackage,
+    PythonPackage,
 )
 from .types.file import File, GetFileRequest, Hash, ListFilesRequest, ListFilesResponse
 from .types.package import (
@@ -69,6 +81,7 @@ from .types.tag import (
     UpdateTagRequest,
 )
 from .types.version import (
+    BatchDeleteVersionsMetadata,
     DeleteVersionRequest,
     GetVersionRequest,
     ListVersionsRequest,
@@ -76,6 +89,11 @@ from .types.version import (
     Version,
     VersionView,
 )
+from .types.vpcsc_config import (
+    GetVPCSCConfigRequest,
+    UpdateVPCSCConfigRequest,
+    VPCSCConfig,
+)
 from .types.yum_artifact import (
     ImportYumArtifactsErrorInfo,
     ImportYumArtifactsGcsSource,
@@ -89,6 +107,7 @@ __all__ = (
     "ArtifactRegistryAsyncClient",
     "AptArtifact",
     "ArtifactRegistryClient",
+    "BatchDeleteVersionsMetadata",
     "CreateRepositoryRequest",
     "CreateTagRequest",
     "DeletePackageRequest",
@@ -99,10 +118,14 @@ __all__ = (
     "File",
     "GetDockerImageRequest",
     "GetFileRequest",
+    "GetMavenArtifactRequest",
+    "GetNpmPackageRequest",
     "GetPackageRequest",
     "GetProjectSettingsRequest",
+    "GetPythonPackageRequest",
     "GetRepositoryRequest",
     "GetTagRequest",
+    "GetVPCSCConfigRequest",
     "GetVersionRequest",
     "Hash",
     "ImportAptArtifactsErrorInfo",
@@ -119,22 +142,33 @@ __all__ = (
     "ListDockerImagesResponse",
     "ListFilesRequest",
     "ListFilesResponse",
+    "ListMavenArtifactsRequest",
+    "ListMavenArtifactsResponse",
+    "ListNpmPackagesRequest",
+    "ListNpmPackagesResponse",
     "ListPackagesRequest",
     "ListPackagesResponse",
+    "ListPythonPackagesRequest",
+    "ListPythonPackagesResponse",
     "ListRepositoriesRequest",
     "ListRepositoriesResponse",
     "ListTagsRequest",
     "ListTagsResponse",
     "ListVersionsRequest",
     "ListVersionsResponse",
+    "MavenArtifact",
+    "NpmPackage",
     "OperationMetadata",
     "Package",
     "ProjectSettings",
+    "PythonPackage",
     "Repository",
     "Tag",
     "UpdateProjectSettingsRequest",
     "UpdateRepositoryRequest",
     "UpdateTagRequest",
+    "UpdateVPCSCConfigRequest",
+    "VPCSCConfig",
     "Version",
     "VersionView",
     "YumArtifact",
